@@ -1,5 +1,5 @@
 """Method for searching user by his AD credentials."""
-from httpx import StatusCode
+import httpx
 
 from botx.clients.methods.base import AuthorizedBotXMethod
 from botx.clients.methods.errors import user_not_found
@@ -12,7 +12,7 @@ class ByLogin(AuthorizedBotXMethod[UserFromSearch]):
     __url__ = "/api/v3/botx/users/by_login"
     __method__ = "GET"
     __returning__ = UserFromSearch
-    __errors_handlers__ = {StatusCode.NOT_FOUND: user_not_found.handle_error}
+    __errors_handlers__ = {httpx.codes.NOT_FOUND: user_not_found.handle_error}
 
     #: AD login to search
     ad_login: str
