@@ -27,5 +27,8 @@ class MessageOptions(BaseModel):
     #: attached to message mentions.
     mentions: List[Mention] = []
 
+    #: don't show next user messages in chat
+    silent_response: bool = False
+
     #: notification configuration.
     notifications: NotificationOptions = NotificationOptions()
